@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::Character;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 use Moo;
 use Types::Common -types;
@@ -23,6 +23,11 @@ has 'name' => (
 	required  => 1,
 );
 
+has 'location' => (
+	is        => 'rwp',
+	isa       => Str | Undef,
+);
+
 has [ qw( meta knows carries achieved ) ] => (
 	is        => 'ro',
 	isa       => HashRef,
