@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::Page;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 use Moo;
 use Types::Common -types;
@@ -17,6 +17,12 @@ use overload (
 	fallback => 1,
 );
 
+has 'id' => (
+	is        => 'ro',
+	isa       => Str,
+	required  => 1,
+);
+
 has 'location' => (
 	is        => 'rwp',
 	isa       => Str,
