@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::PageSource;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 use Story::Interact::Page ();
 use Story::Interact::Syntax ();
@@ -40,9 +40,9 @@ sub get_page {
 	my ( $self, $state, $page_id ) = @_;
 	my $code = $self->get_source_code( $page_id );
 
-	return Story::Interact::Page->new unless $code;
+	return Story::Interact::Page->new( id => ':end' ) unless $code;
 
-	Story::Interact::Syntax::START( $state );
+	Story::Interact::Syntax::START( $state, $page_id );
 	$self->safe->reval( "$code; 1", 1 )
 		or croak( "Died on page '$page_id': $@" );
 	return Story::Interact::Syntax::FINISH( $state );
