@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::State;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 use Story::Interact::Character ();
 
@@ -31,9 +31,27 @@ has 'location' => (
 	builder   => sub { {} },
 );
 
+has 'visited' => (
+	is        => 'ro',
+	isa       => HashRef->of( PositiveOrZeroInt ),
+	builder   => sub { {} },
+);
+
 sub BUILD {
 	my ( $self, $arg ) = @_;
 	$self->character->{player} = Story::Interact::Character->new( name => 'Anon' );
 }
 
+sub player {
+	my ( $self ) = @_;
+	return $self->character->{player};
+}
+
+sub update_from_page {
+	my ( $self, $page ) = @_;
+	++$self->visited->{ $page->id };
+	$self->player->_set_location( $page->location );
+	return $self;
+}
+
 1;
