@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::Syntax;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001000';
+our $VERSION   = '0.001001';
 
 use Story::Interact::Character ();
 use Story::Interact::Page ();
@@ -21,6 +21,7 @@ our @EXPORT = qw(
 	player
 	npc
 	define_npc
+	visited
 	true
 	false
 );
@@ -28,8 +29,8 @@ our @EXPORT = qw(
 my ( $page, $state );
 
 sub START {
-	( $state ) = @_;
-	$page = Story::Interact::Page->new;
+	( $state, my $page_id ) = @_;
+	$page = Story::Interact::Page->new( id => $page_id );
 }
 
 sub text {
@@ -58,7 +59,7 @@ sub location {
 }
 
 sub player () {
-	return $state->character->{player};
+	return $state->player;
 }
 
 sub npc ($) {
@@ -72,7 +73,13 @@ sub define_npc {
 	$state->character->{$code} = Story::Interact::Character->new( %attrs );
 }
 
+sub visited {
+	my ( $code ) = @_ ? @_ : ( $page->id );
+	$state->visited->{$code} //= 0;
+}
+
 sub FINISH {
+	$state->update_from_page( $page );
 	my $return = $page;
 	undef $page;
 	return $return;
